@@ -7,12 +7,9 @@
 #' @importFrom data.table fread
 #' @importFrom reshape2 colsplit
 #' @importFrom tidyr drop_na unite
-#' @importFrom GenomicRanges tileGenome mcols
-#' @importFrom IRanges mergeByOverlaps IRanges
 #' @importFrom stringr str_detect
 #' @importFrom plyr ddply
 #' @importFrom dplyr select mutate everything
-#' @importFrom GenomeInfoDb seqinfo
 #' @param tcga_files GDC files to be read
 #' @param format file format, TCGA or TARGET.
 #' @param binsize the binsize, in base pairs (default 1Mb or 1e6).  This value provides a good balance of resolution and speed with memory sensitive applications.
@@ -40,6 +37,9 @@ formSampleMatrixFromRawGDCData<-function(tcga_files=NULL,format="TARGET",binsize
 freadskip=NULL, parallel = F,debug=F,
 chromosomes=paste0("chr",c(seq(1:22),"X"),"_"),sample_pat="",
 sample_col="sample",chrlabel=">chr", startlabel="begin", endlabel="end",cnlabel="log2") {
+  #importFrom GenomicRanges tileGenome mcols
+  #importFrom IRanges mergeByOverlaps IRanges
+  #importFrom GenomeInfoDb seqinfo
 chr <- if(exists("chr")){get("chr")} else {NULL}
 cn <- if(exists("cn")){get("cn")} else {NULL}
   
@@ -86,7 +86,7 @@ cn <- if(exists("cn")){get("cn")} else {NULL}
   #converts to data table.
   TCGA_CNV_data_gr<-GenomicRanges::GRanges(seqnames = TCGA_CNV_data_range_filtered$`>chr`,ranges = IRanges::IRanges(start = TCGA_CNV_data_range_filtered$begin,end = TCGA_CNV_data_range_filtered$end),... = TCGA_CNV_data_range_filtered[,4:ncol(TCGA_CNV_data_range_filtered)])
   #creates GRanges object with other columns appended. These can be accessed using mcols()
-  bins<-GenomicRanges::tileGenome(seqinfo(BSgenome.Hsapiens.UCSC.hg19::Hsapiens),tilewidth=binsize,cut.last.tile.in.chrom = T)
+  bins<-GenomicRanges::tileGenome(GenomeInfoDb::seqinfo(BSgenome.Hsapiens.UCSC.hg19::Hsapiens),tilewidth=binsize,cut.last.tile.in.chrom = T)
   #creates bins using the tileGenome function.
   if(debug){browser()}
   bins<-bins[as.character(bins@seqnames) %in% gsub("_","",chromosomes)]
