@@ -19,7 +19,7 @@ globalVariables(c("mcols","mcols<-"))
   {
     imported_bed<-rtracklayer::import.bed(breakpoint_fn)
     colsplit_locations<-reshape2::colsplit(string = GenomicRanges::mcols(imported_bed)$name,pattern = "_R_",names=c("otherdata","pos"))[,2]
-    colsplit_locations_gr<-GRanges(colsplit_locations)
+    colsplit_locations_gr<-GenomicRanges::GRanges(colsplit_locations)
     colsplit_id<-reshape2::colsplit(string=reshape2::colsplit(string = GenomicRanges::mcols(imported_bed)$name,pattern = "Id:",names=c("otherdata","id_containing"))[,2],pattern="_",names=c("id","other"))[,1]
     gint<-GenomicInteractions(imported_bed,colsplit_locations_gr,... = colsplit_id)
     colsplit_bed<-reshape2::colsplit(string = GenomicRanges::mcols(imported_bed)$name,pattern = "_",names=c("otherdata","id_containing"))[,1]
